<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl_BE" sourcelanguage="en" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/qtwrapper/callmanager_wrap.h" line="393"/>
        <source>Me</source>
        <translation>Ik</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="61"/>
        <source>Hold</source>
        <translation>In wacht zetten</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="63"/>
        <source>Talking</source>
        <translation>Praten</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="65"/>
        <source>ERROR</source>
        <translation>FOUT</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="67"/>
        <source>Incoming</source>
        <translation>Inkomend</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="69"/>
        <source>Calling</source>
        <translation>Bellen</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="71"/>
        <location filename="../src/chatview.cpp" line="72"/>
        <source>Connecting</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="73"/>
        <source>Searching</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="75"/>
        <source>Inactive</source>
        <translation>Inactief</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="77"/>
        <location filename="../src/api/call.h" line="83"/>
        <location filename="../src/chatview.cpp" line="79"/>
        <source>Finished</source>
        <translation>Beëindigd</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="79"/>
        <source>Timeout</source>
        <translation>Time-out</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="81"/>
        <source>Peer busy</source>
        <translation>Peer is bezig</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="85"/>
        <source>Communication established</source>
        <translation>Communicatie tot stand gebracht</translation>
    </message>
    <message>
        <location filename="../src/api/interaction.h" line="218"/>
        <location filename="../src/authority/storagehelper.cpp" line="136"/>
        <location filename="../src/authority/storagehelper.cpp" line="954"/>
        <source>Invitation received</source>
        <translation>Uitnodiging ontvangen</translation>
    </message>
    <message>
        <location filename="../src/api/interaction.h" line="222"/>
        <source>Contact left conversation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/interaction.h" line="216"/>
        <location filename="../src/authority/storagehelper.cpp" line="133"/>
        <location filename="../src/authority/storagehelper.cpp" line="952"/>
        <source>Contact added</source>
        <translation>Contact toegevoegd</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="110"/>
        <location filename="../src/authority/storagehelper.cpp" line="116"/>
        <location filename="../src/authority/storagehelper.cpp" line="950"/>
        <source>Outgoing call</source>
        <translation>Uitgaande oproep</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="112"/>
        <location filename="../src/authority/storagehelper.cpp" line="122"/>
        <source>Incoming call</source>
        <translation>Inkomende oproep</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="118"/>
        <location filename="../src/authority/storagehelper.cpp" line="948"/>
        <source>Missed outgoing call</source>
        <translation>Gemiste uitgaande oproep</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="124"/>
        <source>Missed incoming call</source>
        <translation>Gemiste inkomende oproep</translation>
    </message>
    <message>
        <location filename="../src/api/interaction.h" line="220"/>
        <location filename="../src/authority/storagehelper.cpp" line="138"/>
        <location filename="../src/authority/storagehelper.cpp" line="956"/>
        <source>Invitation accepted</source>
        <translation>Uitnodiging aanvaard</translation>
    </message>
    <message>
        <location filename="../src/avmodel.cpp" line="339"/>
        <location filename="../src/avmodel.cpp" line="358"/>
        <source>default</source>
        <translation>standaard</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="55"/>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="56"/>
        <source>Trying</source>
        <translation>Poging</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="57"/>
        <source>Ringing</source>
        <translation>Gaat over</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="58"/>
        <source>Being Forwarded</source>
        <translation>Bezig met doorschakelen</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="59"/>
        <source>Queued</source>
        <translation>In wachtrij</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="60"/>
        <source>Progress</source>
        <translation>Voortgang</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="61"/>
        <source>OK</source>
        <translation>Oké</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="73"/>
        <location filename="../src/newcallmodel.cpp" line="62"/>
        <source>Accepted</source>
        <translation>Aanvaard</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="63"/>
        <source>Multiple Choices</source>
        <translation>Meerdere mogelijkheden</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="64"/>
        <source>Moved Permanently</source>
        <translation>Voorgoed verplaatst</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="65"/>
        <source>Moved Temporarily</source>
        <translation>Tijdelijk verplaatst</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="66"/>
        <source>Use Proxy</source>
        <translation>Proxy gebruiken</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="67"/>
        <source>Alternative Service</source>
        <translation>Alternatieve dienst</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="68"/>
        <source>Bad Request</source>
        <translation>Slecht verzoek</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="69"/>
        <source>Unauthorized</source>
        <translation>Ongeautoriseerd</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="70"/>
        <source>Payment Required</source>
        <translation>Betaling vereist</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="71"/>
        <source>Forbidden</source>
        <translation>Verboden</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="72"/>
        <source>Not Found</source>
        <translation>Niet gevonden</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="73"/>
        <source>Method Not Allowed</source>
        <translation>Methode niet toegelaten</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="74"/>
        <location filename="../src/newcallmodel.cpp" line="94"/>
        <source>Not Acceptable</source>
        <translation>Onaanvaardbaar</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="75"/>
        <source>Proxy Authentication Required</source>
        <translation>Proxy-authentificatie vereist</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="76"/>
        <source>Request Timeout</source>
        <translation>Time-out aanvragen</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="77"/>
        <source>Gone</source>
        <translation>Weg</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="78"/>
        <source>Request Entity Too Large</source>
        <translation>Verzoeksentiteit te groot</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="79"/>
        <source>Request URI Too Long</source>
        <translation>Verzoeks-URI te lang</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="80"/>
        <source>Unsupported Media Type</source>
        <translation>Onondersteund mediatype</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="81"/>
        <source>Unsupported URI Scheme</source>
        <translation>Onondersteund URI-schema</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="82"/>
        <source>Bad Extension</source>
        <translation>Slechte extensie</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="83"/>
        <source>Extension Required</source>
        <translation>Extensie vereist</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="84"/>
        <source>Session Timer Too Small</source>
        <translation>Sessietimer te klein</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="85"/>
        <source>Interval Too Brief</source>
        <translation>Interval te kort</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="86"/>
        <source>Temporarily Unavailable</source>
        <translation>Tijdelijk onbeschikbaar</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="87"/>
        <source>Call TSX Does Not Exist</source>
        <translation>Oproeps-TSX bestaat niet</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="88"/>
        <source>Loop Detected</source>
        <translation>Lus gedetecteerd</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="89"/>
        <source>Too Many Hops</source>
        <translation>Te veel sprongen</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="90"/>
        <source>Address Incomplete</source>
        <translation>Onvolledig adres</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="91"/>
        <source>Ambiguous</source>
        <translation>Ambigu</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="92"/>
        <source>Busy</source>
        <translation>Bezig</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="93"/>
        <source>Request Terminated</source>
        <translation>Verzoek beëindigd</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="95"/>
        <source>Bad Event</source>
        <translation>Slechte gebeurtenis</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="96"/>
        <source>Request Updated</source>
        <translation>Verzoek bijgewerkt</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="97"/>
        <source>Request Pending</source>
        <translation>Verzoek in afwachting</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="98"/>
        <source>Undecipherable</source>
        <translation>Onontcijferbaar</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="99"/>
        <source>Internal Server Error</source>
        <translation>Interne serverfout</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="100"/>
        <source>Not Implemented</source>
        <translation>Niet geïmplementeerd</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="101"/>
        <source>Bad Gateway</source>
        <translation>Slechte gateway</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="102"/>
        <source>Service Unavailable</source>
        <translation>Dienst onbeschikbaar</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="103"/>
        <source>Server Timeout</source>
        <translation>Servertime-out</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="104"/>
        <source>Version Not Supported</source>
        <translation>Versie niet ondersteund</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="105"/>
        <source>Message Too Large</source>
        <translation>Bericht te groot</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="106"/>
        <source>Precondition Failure</source>
        <translation>Pre-voorwaardefout</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="107"/>
        <source>Busy Everywhere</source>
        <translation>Overal bezig</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="108"/>
        <source>Call Refused</source>
        <translation>Oproep geweigerd</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="109"/>
        <source>Does Not Exist Anywhere</source>
        <translation>Bestaat nergens</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="110"/>
        <source>Not Acceptable Anywhere</source>
        <translation>Nergens aanvaardbaar</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="30"/>
        <source>Hide chat view</source>
        <translation>Gespreksweergave verbergen</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="31"/>
        <source>Place video call</source>
        <translation>Video-oproep plaatsen</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="32"/>
        <source>Show available plugins</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="33"/>
        <source>Place audio call</source>
        <translation>Audio-oproep plaatsen</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="34"/>
        <source>Add to conversations</source>
        <translation>Toevoegen aan gesprekken</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="35"/>
        <source>Unban contact</source>
        <translation>Contact ontbannen</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="36"/>
        <source>Send</source>
        <translation>Versturen</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="37"/>
        <source>Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="38"/>
        <source>Jump to latest</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="39"/>
        <source>Send file</source>
        <translation>Bestand versturen</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="40"/>
        <source>Add emoji</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="41"/>
        <source>Leave video message</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="42"/>
        <source>Leave audio message</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="44"/>
        <source>Copy to downloads</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="45"/>
        <source>Write to {0}</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="50"/>
        <source>has sent you a conversation request.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="52"/>
        <source>Hello, do you want to join the conversation?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="54"/>
        <source>You have accepted the conversation request.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="56"/>
        <source>We are waiting for another device to synchronize the conversation.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="67"/>
        <source>Accept</source>
        <translation>Aanvaarden</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="68"/>
        <source>Refuse</source>
        <translation>Afwijzen</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="71"/>
        <source>Unable to make contact</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="76"/>
        <source>Waiting for contact</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="77"/>
        <source>Incoming transfer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="78"/>
        <source>Timed out waiting for contact</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="43"/>
        <source>Block</source>
        <translation>Blokkeren</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="47"/>
        <source>Note: an interaction will create a new contact.</source>
        <translation>Let op: een interactie zal een nieuw contact aanmaken.</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="48"/>
        <source>is not in your contacts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="58"/>
        <source>Note: you can automatically accept this invitation by sending a message.</source>
        <translation>Let op: u kunt deze uitnodiging automatisch aanvaarden door een bericht te sturen.</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="59"/>
        <source>{0} days ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="60"/>
        <source>{0} hours ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="62"/>
        <source>{0} minutes ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="74"/>
        <source>Canceled</source>
        <translation>Geannuleerd</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="75"/>
        <source>Ongoing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="59"/>
        <source>%d days ago</source>
        <translation>%d dagen geleden</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="60"/>
        <source>%d hours ago</source>
        <translation>%d uur geleden</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="62"/>
        <source>%d minutes ago</source>
        <translation>%d minuten geleden</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="63"/>
        <source>one day ago</source>
        <translation>een dag geleden</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="64"/>
        <source>one hour ago</source>
        <translation>een uur geleden</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="65"/>
        <source>just now</source>
        <translation>Nu net</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="66"/>
        <source>Failure</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="69"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="70"/>
        <source>Retry</source>
        <translation>Herproberen</translation>
    </message>
</context>
<context>
    <name>lrc::ContactModelPimpl</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="474"/>
        <source>Searching…</source>
        <translation>Bezig met zoeken…</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="999"/>
        <source>Invalid ID</source>
        <translation>Ongeldige ID</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="1002"/>
        <source>Username not found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="1005"/>
        <source>Couldn&apos;t lookup…</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>lrc::api::ContactModel</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="435"/>
        <source>Bad URI scheme</source>
        <translation>Verkeerd URI-schema</translation>
    </message>
</context>
</TS>